# Core Reference

The current AAAX package is small enough that the core concepts map almost one-to-one to the Python modules:

- [Configuration](config.md)
- [Governance](governance.md)
- [Module Loading](modules.md)
- [LibOS Bridge](libos.md)
